import codecs
import json
import os
from datetime import datetime
from pathlib import Path


def make_session_id() -> str:
    return f"{datetime.now():%y%m%d%H%M%S}"


def read_json(path: Path | os.PathLike[str] | str) -> list | dict:
    with codecs.open(path, "r", encoding="utf8") as file:
        return json.load(file)


def replace_n(value: str) -> str:
    return value.replace("\\n", "\n")



from ..chat_item import ChatItem
from pydantic import Field

from . import InnerContextWithState


class ChatItemWithState(ChatItem):
    inner_context: InnerContextWithState = Field(alias="InnerContext")



from ._base import _Base
from .enums import TrackIdEnum, StatesEnum, MTRSLabelEnum
from .chat_item import ChatItem, OuterContextItem, InnerContextItem, ReplicaItem
from .chat_item_with_state import ChatItemWithState, InnerContextWithState, ReplicaWithState
from .base_config_models import GigaChatConfig



from datetime import datetime

from pydantic import Field, field_validator, field_serializer

from .. import _Base

_TIME_FORMAT: str = "%Y-%m-%d-%H-%M-%S"
_EXAMPLE_DATETIME: datetime = datetime(1970, 1, 1, 0, 0, 0)


class ReplicaItem(_Base):
    body: str = Field("", alias="Body", examples=["Привет"])
    role: bool = Field(False, alias="Role", description="True = ai, False = client", examples=[False])
    date_time: datetime = Field(
        _EXAMPLE_DATETIME,
        alias="DateTime",
        examples=[_EXAMPLE_DATETIME.strftime(_TIME_FORMAT)],
        description=f"Format: {_TIME_FORMAT}",
    )
    previous_score: float | None = Field(None, alias="PreviousScore", exclude=True, deprecated=True)

    @field_validator("date_time", mode="before")
    @classmethod
    def convert_date_time(cls, timestamp: str | datetime) -> datetime:
        if isinstance(timestamp, datetime):
            return timestamp
        return datetime.strptime(timestamp, _TIME_FORMAT)

    @field_serializer("date_time")
    def serialize_date_time(self, timestamp: datetime) -> str:
        return timestamp.strftime(_TIME_FORMAT)



from ..chat_item import InnerContextItem
from pydantic import Field

from . import ReplicaWithState


class InnerContextWithState(InnerContextItem):
    replicas: list[ReplicaWithState] = Field(alias="Replicas")
